@@ -5,7 +5,7 @@
 
 #![allow(dead_code)]
 
-use std::os;
+use std::{mem, os};
 
 /// This enumeration is the list of the possible status outcomes for the
 /// SQL statement execution on SQLite3.
@@ -264,7 +264,6 @@ impl SqlitePrimaryResult {
     /// Converts i8 type value into SqlitePrimaryResult and returns it.
     ///
     /// # Usage
-    /// ```ignore
     /// SqlitePrimaryResult::from_i8(7),
     /// ```
     #[inline]
@@ -318,6 +317,16 @@ pub struct sqlite3_stmt {
     __: [u8; 0],
 }
 
+#[inline(always)]
+pub fn sqlite_transient() -> Option<unsafe extern "C" fn(lifetime: *mut os::raw::c_void)> {
+    Some(unsafe { mem::transmute(-1_isize) })
+}
+
+#[inline(always)]
+pub fn sqlite_static() -> Option<unsafe extern "C" fn(lifetime: *mut os::raw::c_void)> {
+    None
+}
+
 extern "C" {
     pub(crate) fn sqlite3_open(
         file_path: *const os::raw::c_char,
@@ -374,4 +383,40 @@ extern "C" {
         stmt: *mut sqlite3_stmt,
         col_index: os::raw::c_int,
     ) -> os::raw::c_int;
+
+    pub fn sqlite3_bind_blob(
+        stmt: *mut sqlite3_stmt,
+        col_index: os::raw::c_int,
+        val: *const os::raw::c_void,
+        val_bytes: os::raw::c_int,
+        val_lifetime: Option<unsafe extern "C" fn(lifetime: *mut os::raw::c_void)>,
+    ) -> os::raw::c_int;
+
+    pub fn sqlite3_bind_zeroblob64(
+        stmt: *mut sqlite3_stmt,
+        col_index: os::raw::c_int,
+        val: os::raw::c_ulonglong,
+    ) -> os::raw::c_int;
+
+    pub fn sqlite3_bind_double(
+        stmt: *mut sqlite3_stmt,
+        col_index: os::raw::c_int,
+        val: f64,
+    ) -> os::raw::c_int;
+
+    pub fn sqlite3_bind_text(
+        stmt: *mut sqlite3_stmt,
+        col_index: os::raw::c_int,
+        val: *const os::raw::c_char,
+        val_bytes: os::raw::c_int,
+        val_lifetime: Option<unsafe extern "C" fn(lifetime: *mut os::raw::c_void)>,
+    ) -> os::raw::c_int;
+
+    pub fn sqlite3_bind_int64(
+        stmt: *mut sqlite3_stmt,
+        col_index: os::raw::c_int,
+        val: os::raw::c_longlong,
+    ) -> os::raw::c_int;
+
+    pub fn sqlite3_bind_null(stmt: *mut sqlite3_stmt, col_index: os::raw::c_int) -> os::raw::c_int;
 }
